@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package MooseX::MethodAttributes::Role;
-our $VERSION = '0.16_01';
+our $VERSION = '0.17';
 
 # ABSTRACT: code attribute introspection
 
@@ -14,7 +14,7 @@ use Moose::Util qw/find_meta does_role ensure_all_roles/;
 use MooseX::MethodAttributes::Role::Meta::Role ();
 
 
-Moose::Exporter->setup_import_methods;
+Moose::Exporter->setup_import_methods( also => 'Moose::Role' );
 
 sub init_meta {
     my ($class, %options) = @_;
@@ -52,7 +52,7 @@ MooseX::MethodAttributes::Role - code attribute introspection
 
 =head1 VERSION
 
-version 0.16_01
+version 0.17
 
 =head1 SYNOPSIS
 
@@ -86,7 +86,7 @@ init_meta
 This software is copyright (c) 2009 by Florian Ragwitz.
 
 This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
+the same terms as perl itself.
 
 =cut 
 
