@@ -1,7 +1,7 @@
 package OtherRoleWithAttributes;
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
-use Moose::Role -traits => 'MethodAttributes';
+use MooseX::MethodAttributes::Role;
 use namespace::clean -except => 'meta';
 
 sub bar : AnAttr { 'bar' }
