@@ -1,5 +1,5 @@
 package UsesMultipleRoles;
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 use Moose;
 use namespace::clean -except => 'meta';
@@ -9,5 +9,5 @@ with qw/
     OtherRoleWithAttributes
 /;
 
-__PACKAGE__->meta->make_immutable;
+#__PACKAGE__->meta->make_immutable;
 
